/*
 * File: HAMparser.cpp
 *
 * Written by Peter Horak in November 2013 for GreenCube (based on parser.cpp).
 *
 * Purpose: parse  HAM data from the GreenCube payload
 */

#include <iostream>
#include <iomanip>
#include <string>
#include <sstream>
#include <stdio.h>
#include <math.h>

using namespace std;

int main(int argc, char **argv)
{
    // To hold the data
    char c; // 1 byte
    
    // Convert the data into text and output it to the data buffer
    do {
        // Find the start of a line
        while ((c != '/') && !cin.eof())
            cin.read((&c),sizeof(c));
        
        // To temporarily store the GPS tring
        stringstream gps_buf;
        do {
            cin.read((&c),sizeof(c));
            gps_buf << c;
        } while ((c != 'C') && !cin.eof());
        
        // Values to read fromt the GPS string
        unsigned int timeg;
        float lat,lng;
        int alt,temp;
        char sign;
        
        sscanf(gps_buf.str().c_str(),"%dh%fN/%fWO/A=%d%c%d",&timeg,&lat,&lng,&alt,&sign,&temp);
        
        // Convert the time to hh:mm:ss format
        int hr = timeg/10000;
        int mi = timeg/100-hr*100;
        int sc = timeg-hr*10000-mi*100;
        
        // Get GPS coordinates entirely in degrees
        int deg = round(lat/100);
        float min = lat - deg*100;
        lat = deg + min/60.0;
        
        deg = round(lng/100);
        min = lng - deg*100;
        lng = -1.0*(deg+min/60.0); // -1 b/c always in NE
        
        if (alt != 0)
        {
            cout << (hr*3600+mi*60+sc) << "\t" << setw(7) << lat << "\t" << setw(8) << lng << "\t" << alt << "\t" << sign << temp << endl;
        }
    } while (cin && !cin.eof());
}

